@@ -7,10 +7,31 @@
   form
 }
 
+.reformat_resid_model <- function(resid.model,family) {
+  if ( ! is.null(resid.model)) {
+    if ( ! is.null(form <- resid.model$formula)) {
+      # old comment, maybe obsolete:
+      ## oricall$resid.model$formula <- ... is wrong if oricall$resid.model is a promise
+      ## we can get info about the promise by using pryr::uneval(resid.model)
+      ## class(uneval(resid.model)) may be "bytecode" if the corrHLfit argument was already an evaluated promise
+      ## otherwise class(uneval(resid.model)) may be a "call".
+      ## if needed, uneval is minimal R code  + the C++ code in promise.cpp: promise_code(resid_model) might suffice.
+      resid.model$formula <- .stripFormula(form)
+    } else {
+      resid.model <- list(formula=.stripFormula(resid.model), ## otherwise it retains the local environment of the fn in which it is match.call()ed!
+                          family=family)
+    }
+    resid.model$fixed <- as.list(resid.model$fixed) ## converts NULL to list() as exp'd for 'fixed' in fitme_body()
+  }
+  return(resid.model)
+}
+
 stripHLfit <- function(object,...) {
   if (inherits(object,"HLfit")) {
     ######## clean matrices
-    for (st in names(object$envir)) object$envir[[st]] <- NULL
+    stripnames <- names(object$envir)
+    stripnames <- setdiff(stripnames,c("G_CHMfactor","chol_Q","ZtW")) ## excepton for those that are not reconstructed on request
+    for (st in stripnames) object$envir[[st]] <- NULL
     if (object$spaMM.version <= "1.10.3") { ## for later version, this part of code documents some obscure issues.
       ######### family matters ...
       ## family$variance, $simulate, $validmu, $aic, $dev.resids get an environment that seems to be 
@@ -36,18 +57,18 @@ stripHLfit <- function(object,...) {
       if ( ! is.null(object$phi.object$glm_phi$family)) 
         parent.env(environment(object$phi.object$glm_phi$family$aic)) <- environment(stats::Gamma)
       ######### formula matters; ideally already previously cleaned 
-      if ( ! is.null(fitcall <- attr(object,"corrHLfitcall"))) {
-        attr(object,"corrHLfitcall")$formula <- .stripFormula(fitcall$formula)  
-        if ( ! is.null(form <- fitcall$resid.formula)) 
-          attr(object,"corrHLfitcall")$resid.formula <- .stripFormula(form)
-        if ( ! is.null(form <- fitcall$resid.model$formula)) 
-          attr(object,"corrHLfitcall")$resid.model$formula <- .stripFormula(form)
-      }
-      if ( ! is.null(fitcall <- attr(object,"fitmecall"))) {
-        attr(object,"fitmecall")$formula <- .stripFormula(fitcall$formula)  
-        if ( ! is.null(form <- fitcall$resid.model$formula)) 
-          attr(object,"fitmecall")$resid.model$formula <- .stripFormula(form)
-      }
+      # if ( ! is.null(fitcall <- attr(object,"corrHLfitcall"))) {
+      #   attr(object,"corrHLfitcall")$formula <- .stripFormula(fitcall$formula)  
+      #   if ( ! is.null(form <- fitcall$resid.formula)) 
+      #     attr(object,"corrHLfitcall")$resid.formula <- .stripFormula(form)
+      #   if ( ! is.null(form <- fitcall$resid.model$formula)) 
+      #     attr(object,"corrHLfitcall")$resid.model$formula <- .stripFormula(form)
+      # }
+      # if ( ! is.null(fitcall <- attr(object,"fitmecall"))) {
+      #   attr(object,"fitmecall")$formula <- .stripFormula(fitcall$formula)  
+      #   if ( ! is.null(form <- fitcall$resid.model$formula)) 
+      #     attr(object,"fitmecall")$resid.model$formula <- .stripFormula(form)
+      # }
       ######### optr matters 
       attr(attr(object,"optimInfo")$optim.pars,"optr")$eval_f <- NULL
       attr(attr(object,"optimInfo")$optim.pars,"optr")$nloptr_environment <- NULL
