@@ -6,12 +6,12 @@ loafit <- corrHLfit(cbind(npos,ntot-npos)~elev1+elev2+elev3+elev4+maxNDVI1+seNDV
           +Matern(1|longitude+latitude),
           data=Loaloa[1:30,],family=binomial(),
           init.corrHLfit=list(Nugget=0.1),ranFix=list(nu=0.5)) 
-
-if (is.null(loafit$corrPars[["1"]])) { ## old sp2 code
-  testthat::expect_equal(attr(loafit$corrPars,"type"),list(nu="fix",Nugget="outer",rho="outer"))
-  testthat::expect_equal(loafit$corrPars$Nugget,0.0458,tolerance=5e-5) 
+corrpars <- get_ranPars(loafit,which="corrPars")
+if (is.null(corrpars[["1"]])) { ## old sp2 code
+  testthat::expect_equal(attr(corrpars,"type"),list(nu="fix",Nugget="outer",rho="outer"))
+  testthat::expect_equal(corrpars$Nugget,0.0458,tolerance=5e-5) 
 } else { # future spaMM3.0 code
-  testthat::expect_equal(attr(loafit$corrPars,"type")[["1"]],list(nu="fix",Nugget="outer",rho="outer"))
-  testthat::expect_equal(loafit$corrPars[["1"]]$Nugget,0.0458,tolerance=5e-5) 
+  testthat::expect_equal(attr(corrpars,"type")[["1"]],list(nu="fix",Nugget="outer",rho="outer"))
+  testthat::expect_equal(corrpars[["1"]]$Nugget,0.0458,tolerance=5e-5) 
 }
 ## NB flat p_bv for Nugget; nloptr and bobyqa reach slightly diff values and L-BFGS-B performs poorly
